@@ -69,6 +69,7 @@ from .Table import Table
 from .Tabs import Tabs
 from .Text import Text
 from .TextInput import TextInput
+from .Textarea import Textarea
 from .ThemeIcon import ThemeIcon
 from .ThemeSwitcher import ThemeSwitcher
 from .TimeInput import TimeInput
@@ -149,6 +150,7 @@ __all__ = [
     "Tabs",
     "Text",
     "TextInput",
+    "Textarea",
     "ThemeIcon",
     "ThemeSwitcher",
     "TimeInput",
